@@ -4,16 +4,14 @@ Main interface for sts service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_sts import (
         Client,
         STSClient,
     )
 
-    session = boto3.Session()
-
-    client: STSClient = boto3.client("sts")
-    session_client: STSClient = session.client("sts")
+    session = Session()
+    client: STSClient = session.client("sts")
     ```
 """
 from .client import STSClient
