@@ -75,10 +75,10 @@ class STSClient(BaseClient):
         *,
         RoleArn: str,
         RoleSessionName: str,
-        PolicyArns: Sequence["PolicyDescriptorTypeTypeDef"] = ...,
+        PolicyArns: Sequence[PolicyDescriptorTypeTypeDef] = ...,
         Policy: str = ...,
         DurationSeconds: int = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         TransitiveTagKeys: Sequence[str] = ...,
         ExternalId: str = ...,
         SerialNumber: str = ...,
@@ -99,7 +99,7 @@ class STSClient(BaseClient):
         RoleArn: str,
         PrincipalArn: str,
         SAMLAssertion: str,
-        PolicyArns: Sequence["PolicyDescriptorTypeTypeDef"] = ...,
+        PolicyArns: Sequence[PolicyDescriptorTypeTypeDef] = ...,
         Policy: str = ...,
         DurationSeconds: int = ...
     ) -> AssumeRoleWithSAMLResponseTypeDef:
@@ -118,7 +118,7 @@ class STSClient(BaseClient):
         RoleSessionName: str,
         WebIdentityToken: str,
         ProviderId: str = ...,
-        PolicyArns: Sequence["PolicyDescriptorTypeTypeDef"] = ...,
+        PolicyArns: Sequence[PolicyDescriptorTypeTypeDef] = ...,
         Policy: str = ...,
         DurationSeconds: int = ...
     ) -> AssumeRoleWithWebIdentityResponseTypeDef:
@@ -138,6 +138,14 @@ class STSClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sts/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sts.html#STS.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sts/client/#close)
+        """
+
     def decode_authorization_message(
         self, *, EncodedMessage: str
     ) -> DecodeAuthorizationMessageResponseTypeDef:
@@ -185,9 +193,9 @@ class STSClient(BaseClient):
         *,
         Name: str,
         Policy: str = ...,
-        PolicyArns: Sequence["PolicyDescriptorTypeTypeDef"] = ...,
+        PolicyArns: Sequence[PolicyDescriptorTypeTypeDef] = ...,
         DurationSeconds: int = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> GetFederationTokenResponseTypeDef:
         """
         Returns a set of temporary security credentials (consisting of an access key ID,
