@@ -6,9 +6,9 @@ Type annotations for sts service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_sts.type_defs import AssumeRoleRequestRequestTypeDef
+    from mypy_boto3_sts.type_defs import PolicyDescriptorTypeTypeDef
 
-    data: AssumeRoleRequestRequestTypeDef = {...}
+    data: PolicyDescriptorTypeTypeDef = {...}
     ```
 """
 import sys
@@ -22,150 +22,42 @@ else:
 
 
 __all__ = (
-    "AssumeRoleRequestRequestTypeDef",
-    "AssumeRoleResponseTypeDef",
-    "AssumeRoleWithSAMLRequestRequestTypeDef",
-    "AssumeRoleWithSAMLResponseTypeDef",
-    "AssumeRoleWithWebIdentityRequestRequestTypeDef",
-    "AssumeRoleWithWebIdentityResponseTypeDef",
+    "PolicyDescriptorTypeTypeDef",
+    "TagTypeDef",
     "AssumedRoleUserTypeDef",
     "CredentialsTypeDef",
+    "ResponseMetadataTypeDef",
     "DecodeAuthorizationMessageRequestRequestTypeDef",
-    "DecodeAuthorizationMessageResponseTypeDef",
     "FederatedUserTypeDef",
     "GetAccessKeyInfoRequestRequestTypeDef",
+    "GetSessionTokenRequestRequestTypeDef",
+    "AssumeRoleWithSAMLRequestRequestTypeDef",
+    "AssumeRoleWithWebIdentityRequestRequestTypeDef",
+    "AssumeRoleRequestRequestTypeDef",
+    "GetFederationTokenRequestRequestTypeDef",
+    "AssumeRoleResponseTypeDef",
+    "AssumeRoleWithSAMLResponseTypeDef",
+    "AssumeRoleWithWebIdentityResponseTypeDef",
+    "DecodeAuthorizationMessageResponseTypeDef",
     "GetAccessKeyInfoResponseTypeDef",
     "GetCallerIdentityResponseTypeDef",
-    "GetFederationTokenRequestRequestTypeDef",
-    "GetFederationTokenResponseTypeDef",
-    "GetSessionTokenRequestRequestTypeDef",
     "GetSessionTokenResponseTypeDef",
+    "GetFederationTokenResponseTypeDef",
+)
+
+PolicyDescriptorTypeTypeDef = TypedDict(
     "PolicyDescriptorTypeTypeDef",
-    "ResponseMetadataTypeDef",
+    {
+        "arn": str,
+    },
+    total=False,
+)
+
+TagTypeDef = TypedDict(
     "TagTypeDef",
-)
-
-_RequiredAssumeRoleRequestRequestTypeDef = TypedDict(
-    "_RequiredAssumeRoleRequestRequestTypeDef",
     {
-        "RoleArn": str,
-        "RoleSessionName": str,
-    },
-)
-_OptionalAssumeRoleRequestRequestTypeDef = TypedDict(
-    "_OptionalAssumeRoleRequestRequestTypeDef",
-    {
-        "PolicyArns": Sequence["PolicyDescriptorTypeTypeDef"],
-        "Policy": str,
-        "DurationSeconds": int,
-        "Tags": Sequence["TagTypeDef"],
-        "TransitiveTagKeys": Sequence[str],
-        "ExternalId": str,
-        "SerialNumber": str,
-        "TokenCode": str,
-        "SourceIdentity": str,
-    },
-    total=False,
-)
-
-
-class AssumeRoleRequestRequestTypeDef(
-    _RequiredAssumeRoleRequestRequestTypeDef, _OptionalAssumeRoleRequestRequestTypeDef
-):
-    pass
-
-
-AssumeRoleResponseTypeDef = TypedDict(
-    "AssumeRoleResponseTypeDef",
-    {
-        "Credentials": "CredentialsTypeDef",
-        "AssumedRoleUser": "AssumedRoleUserTypeDef",
-        "PackedPolicySize": int,
-        "SourceIdentity": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredAssumeRoleWithSAMLRequestRequestTypeDef = TypedDict(
-    "_RequiredAssumeRoleWithSAMLRequestRequestTypeDef",
-    {
-        "RoleArn": str,
-        "PrincipalArn": str,
-        "SAMLAssertion": str,
-    },
-)
-_OptionalAssumeRoleWithSAMLRequestRequestTypeDef = TypedDict(
-    "_OptionalAssumeRoleWithSAMLRequestRequestTypeDef",
-    {
-        "PolicyArns": Sequence["PolicyDescriptorTypeTypeDef"],
-        "Policy": str,
-        "DurationSeconds": int,
-    },
-    total=False,
-)
-
-
-class AssumeRoleWithSAMLRequestRequestTypeDef(
-    _RequiredAssumeRoleWithSAMLRequestRequestTypeDef,
-    _OptionalAssumeRoleWithSAMLRequestRequestTypeDef,
-):
-    pass
-
-
-AssumeRoleWithSAMLResponseTypeDef = TypedDict(
-    "AssumeRoleWithSAMLResponseTypeDef",
-    {
-        "Credentials": "CredentialsTypeDef",
-        "AssumedRoleUser": "AssumedRoleUserTypeDef",
-        "PackedPolicySize": int,
-        "Subject": str,
-        "SubjectType": str,
-        "Issuer": str,
-        "Audience": str,
-        "NameQualifier": str,
-        "SourceIdentity": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredAssumeRoleWithWebIdentityRequestRequestTypeDef = TypedDict(
-    "_RequiredAssumeRoleWithWebIdentityRequestRequestTypeDef",
-    {
-        "RoleArn": str,
-        "RoleSessionName": str,
-        "WebIdentityToken": str,
-    },
-)
-_OptionalAssumeRoleWithWebIdentityRequestRequestTypeDef = TypedDict(
-    "_OptionalAssumeRoleWithWebIdentityRequestRequestTypeDef",
-    {
-        "ProviderId": str,
-        "PolicyArns": Sequence["PolicyDescriptorTypeTypeDef"],
-        "Policy": str,
-        "DurationSeconds": int,
-    },
-    total=False,
-)
-
-
-class AssumeRoleWithWebIdentityRequestRequestTypeDef(
-    _RequiredAssumeRoleWithWebIdentityRequestRequestTypeDef,
-    _OptionalAssumeRoleWithWebIdentityRequestRequestTypeDef,
-):
-    pass
-
-
-AssumeRoleWithWebIdentityResponseTypeDef = TypedDict(
-    "AssumeRoleWithWebIdentityResponseTypeDef",
-    {
-        "Credentials": "CredentialsTypeDef",
-        "SubjectFromWebIdentityToken": str,
-        "AssumedRoleUser": "AssumedRoleUserTypeDef",
-        "PackedPolicySize": int,
-        "Provider": str,
-        "Audience": str,
-        "SourceIdentity": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "Key": str,
+        "Value": str,
     },
 )
 
@@ -187,6 +79,17 @@ CredentialsTypeDef = TypedDict(
     },
 )
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
+    },
+)
+
 DecodeAuthorizationMessageRequestRequestTypeDef = TypedDict(
     "DecodeAuthorizationMessageRequestRequestTypeDef",
     {
@@ -194,14 +97,6 @@ DecodeAuthorizationMessageRequestRequestTypeDef = TypedDict(
     },
 )
 
-DecodeAuthorizationMessageResponseTypeDef = TypedDict(
-    "DecodeAuthorizationMessageResponseTypeDef",
-    {
-        "DecodedMessage": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 FederatedUserTypeDef = TypedDict(
     "FederatedUserTypeDef",
     {
@@ -217,23 +112,98 @@ GetAccessKeyInfoRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetAccessKeyInfoResponseTypeDef = TypedDict(
-    "GetAccessKeyInfoResponseTypeDef",
+GetSessionTokenRequestRequestTypeDef = TypedDict(
+    "GetSessionTokenRequestRequestTypeDef",
     {
-        "Account": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "DurationSeconds": int,
+        "SerialNumber": str,
+        "TokenCode": str,
     },
+    total=False,
 )
 
-GetCallerIdentityResponseTypeDef = TypedDict(
-    "GetCallerIdentityResponseTypeDef",
+_RequiredAssumeRoleWithSAMLRequestRequestTypeDef = TypedDict(
+    "_RequiredAssumeRoleWithSAMLRequestRequestTypeDef",
     {
-        "UserId": str,
-        "Account": str,
-        "Arn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RoleArn": str,
+        "PrincipalArn": str,
+        "SAMLAssertion": str,
     },
 )
+_OptionalAssumeRoleWithSAMLRequestRequestTypeDef = TypedDict(
+    "_OptionalAssumeRoleWithSAMLRequestRequestTypeDef",
+    {
+        "PolicyArns": Sequence[PolicyDescriptorTypeTypeDef],
+        "Policy": str,
+        "DurationSeconds": int,
+    },
+    total=False,
+)
+
+
+class AssumeRoleWithSAMLRequestRequestTypeDef(
+    _RequiredAssumeRoleWithSAMLRequestRequestTypeDef,
+    _OptionalAssumeRoleWithSAMLRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredAssumeRoleWithWebIdentityRequestRequestTypeDef = TypedDict(
+    "_RequiredAssumeRoleWithWebIdentityRequestRequestTypeDef",
+    {
+        "RoleArn": str,
+        "RoleSessionName": str,
+        "WebIdentityToken": str,
+    },
+)
+_OptionalAssumeRoleWithWebIdentityRequestRequestTypeDef = TypedDict(
+    "_OptionalAssumeRoleWithWebIdentityRequestRequestTypeDef",
+    {
+        "ProviderId": str,
+        "PolicyArns": Sequence[PolicyDescriptorTypeTypeDef],
+        "Policy": str,
+        "DurationSeconds": int,
+    },
+    total=False,
+)
+
+
+class AssumeRoleWithWebIdentityRequestRequestTypeDef(
+    _RequiredAssumeRoleWithWebIdentityRequestRequestTypeDef,
+    _OptionalAssumeRoleWithWebIdentityRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredAssumeRoleRequestRequestTypeDef = TypedDict(
+    "_RequiredAssumeRoleRequestRequestTypeDef",
+    {
+        "RoleArn": str,
+        "RoleSessionName": str,
+    },
+)
+_OptionalAssumeRoleRequestRequestTypeDef = TypedDict(
+    "_OptionalAssumeRoleRequestRequestTypeDef",
+    {
+        "PolicyArns": Sequence[PolicyDescriptorTypeTypeDef],
+        "Policy": str,
+        "DurationSeconds": int,
+        "Tags": Sequence[TagTypeDef],
+        "TransitiveTagKeys": Sequence[str],
+        "ExternalId": str,
+        "SerialNumber": str,
+        "TokenCode": str,
+        "SourceIdentity": str,
+    },
+    total=False,
+)
+
+
+class AssumeRoleRequestRequestTypeDef(
+    _RequiredAssumeRoleRequestRequestTypeDef, _OptionalAssumeRoleRequestRequestTypeDef
+):
+    pass
+
 
 _RequiredGetFederationTokenRequestRequestTypeDef = TypedDict(
     "_RequiredGetFederationTokenRequestRequestTypeDef",
@@ -245,9 +215,9 @@ _OptionalGetFederationTokenRequestRequestTypeDef = TypedDict(
     "_OptionalGetFederationTokenRequestRequestTypeDef",
     {
         "Policy": str,
-        "PolicyArns": Sequence["PolicyDescriptorTypeTypeDef"],
+        "PolicyArns": Sequence[PolicyDescriptorTypeTypeDef],
         "DurationSeconds": int,
-        "Tags": Sequence["TagTypeDef"],
+        "Tags": Sequence[TagTypeDef],
     },
     total=False,
 )
@@ -260,57 +230,87 @@ class GetFederationTokenRequestRequestTypeDef(
     pass
 
 
-GetFederationTokenResponseTypeDef = TypedDict(
-    "GetFederationTokenResponseTypeDef",
+AssumeRoleResponseTypeDef = TypedDict(
+    "AssumeRoleResponseTypeDef",
     {
-        "Credentials": "CredentialsTypeDef",
-        "FederatedUser": "FederatedUserTypeDef",
+        "Credentials": CredentialsTypeDef,
+        "AssumedRoleUser": AssumedRoleUserTypeDef,
         "PackedPolicySize": int,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "SourceIdentity": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
 
-GetSessionTokenRequestRequestTypeDef = TypedDict(
-    "GetSessionTokenRequestRequestTypeDef",
+AssumeRoleWithSAMLResponseTypeDef = TypedDict(
+    "AssumeRoleWithSAMLResponseTypeDef",
     {
-        "DurationSeconds": int,
-        "SerialNumber": str,
-        "TokenCode": str,
+        "Credentials": CredentialsTypeDef,
+        "AssumedRoleUser": AssumedRoleUserTypeDef,
+        "PackedPolicySize": int,
+        "Subject": str,
+        "SubjectType": str,
+        "Issuer": str,
+        "Audience": str,
+        "NameQualifier": str,
+        "SourceIdentity": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+AssumeRoleWithWebIdentityResponseTypeDef = TypedDict(
+    "AssumeRoleWithWebIdentityResponseTypeDef",
+    {
+        "Credentials": CredentialsTypeDef,
+        "SubjectFromWebIdentityToken": str,
+        "AssumedRoleUser": AssumedRoleUserTypeDef,
+        "PackedPolicySize": int,
+        "Provider": str,
+        "Audience": str,
+        "SourceIdentity": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DecodeAuthorizationMessageResponseTypeDef = TypedDict(
+    "DecodeAuthorizationMessageResponseTypeDef",
+    {
+        "DecodedMessage": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetAccessKeyInfoResponseTypeDef = TypedDict(
+    "GetAccessKeyInfoResponseTypeDef",
+    {
+        "Account": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetCallerIdentityResponseTypeDef = TypedDict(
+    "GetCallerIdentityResponseTypeDef",
+    {
+        "UserId": str,
+        "Account": str,
+        "Arn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
-    total=False,
 )
 
 GetSessionTokenResponseTypeDef = TypedDict(
     "GetSessionTokenResponseTypeDef",
     {
-        "Credentials": "CredentialsTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "Credentials": CredentialsTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
 
-PolicyDescriptorTypeTypeDef = TypedDict(
-    "PolicyDescriptorTypeTypeDef",
+GetFederationTokenResponseTypeDef = TypedDict(
+    "GetFederationTokenResponseTypeDef",
     {
-        "arn": str,
-    },
-    total=False,
-)
-
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
-    },
-)
-
-TagTypeDef = TypedDict(
-    "TagTypeDef",
-    {
-        "Key": str,
-        "Value": str,
+        "Credentials": CredentialsTypeDef,
+        "FederatedUser": FederatedUserTypeDef,
+        "PackedPolicySize": int,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
